Summary Method for Object of Class metadynmeta
Source: R/metaDyn-methods-metadynmeta.R
summary.metadynmeta.RdSummary Method for Object of Class metadynmeta
Usage
# S3 method for class 'metadynmeta'
summary(
object,
alpha = NULL,
ci_type = "wald",
robust = NULL,
nrep = 1000L,
seed = NULL,
ncores = NULL,
digits = 4,
...
)Arguments
- object
an object of class
metadynmeta.- alpha
Numeric vector. Significance level \(\alpha\). If
NULL, the function will checkobjectforalphaused in model fitting.- ci_type
Character string. Valid values are
"wald"and"mc".- robust
Logical. If
TRUE, use robust (sandwich) sampling variance-covariance matrix. IfFALSE, use normal theory sampling variance-covariance matrix. IfNULL, the function will checkobjectif robust standard errors are available.- nrep
Positive integer. Number of replications for
ci_type = "mc".- seed
Random seed for
ci_type = "mc".- ncores
Positive integer. Number of cores to use for
ci_type = "mc".- digits
Integer indicating the number of decimal places to display.
- ...
further arguments.