Summary Method for Object of Class metadynmeta
Source: R/metaDyn-methods-metadynmeta.R
summary.metadynmeta.RdSummary Method for Object of Class metadynmeta
Usage
# S3 method for class 'metadynmeta'
summary(object, alpha = NULL, robust = NULL, digits = 4, ...)Arguments
- object
an object of class
metadynmeta.- alpha
Numeric vector. Significance level \(\alpha\). If
NULL, the function will checkobjectforalphaused in model fitting.- robust
Logical. If
TRUE, use robust (sandwich) sampling variance-covariance matrix. IfFALSE, use normal theory sampling variance-covariance matrix. IfNULL, the function will checkobjectif robust standard errors are available.- digits
Integer indicating the number of decimal places to display.
- ...
further arguments.